SLI is an FO(·) reasoning engine written in Rust.
The sli-lib package provides a Python API based on the Rust library, allowing for the manipulation of FO(·) and the execution of inference tasks on knowledge represented in FO(·).

- Documentation: <https://sli-lib.gitlab.io/sli/python>
- Source code: <https://gitlab.com/sli-lib/SLI>
